<!-- DateTimeElement -->
<div>
    {% include 'flasky_settings/setting/sub/title_div.html' %}

    <div class="input-group input-group-sm log-event" data-td-target-input="nearest" data-td-target-toggle="nearest">

        <input type="text" class="init-datetime form-control form-control-sm observed-input" />
      </div>
</div>