<!-- StringElement -->
<div>
    {% include 'flasky_settings/setting/sub/title_div.html' %}

     <input type="text" class="form-control form-control-sm observed-input" placeholder="{{ element.placeholder }}" value="{%- if setting_group -%}{{ setting_group[element.key] }}{%- else -%}{{ element.default }}{%- endif -%}">
</div>