<div class="d-flex justify-content-between align-items-center">
    {% if element.title %}
        <b class="setting-element-title">{{ element.title }}</b>
    {% endif %}

    {% if element.description %}
        <i class="setting-element-description">{{ element.description }}</i>
    {% endif %}
</div>